@charset "UTF-8";
.select2-result-repository {
  padding-top: 4px;
  padding-bottom: 3px; }
  .select2-result-repository__avatar {
    float: left;
    width: 60px;
    margin-right: 10px; }
    .select2-result-repository__avatar img {
      width: 100%;
      height: auto;
      border-radius: 2px; }
  .select2-result-repository__meta {
    margin-left: 70px; }
  .select2-result-repository__title {
    color: black;
    font-weight: bold;
    word-wrap: break-word;
    line-height: 1.1;
    margin-bottom: 4px; }
  .select2-result-repository__forks, .select2-result-repository__stargazers {
    margin-right: 1em; }
  .select2-result-repository__forks, .select2-result-repository__stargazers, .select2-result-repository__watchers {
    display: inline-block;
    color: #aaa;
    font-size: 11px; }
  .select2-result-repository__description {
    font-size: 13px;
    color: #777;
    margin-top: 4px; }
  .select2-results__option--highlighted .select2-result-repository__title {
    color: white; }
  .select2-results__option--highlighted .select2-result-repository__forks, .select2-results__option--highlighted .select2-result-repository__stargazers, .select2-results__option--highlighted .select2-result-repository__description, .select2-results__option--highlighted .select2-result-repository__watchers {
    color: #c6dcef; }

.s2-docs-sidebar.affix {
  position: static; }
@media (min-width: 768px) {
  .s2-docs-sidebar {
    padding-left: 20px; } }

.s2-docs-sidenav {
  margin-top: 20px;
  margin-bottom: 20px; }

.s2-docs-sidebar .nav > li > a {
  margin-left: -1px;
  display: block;
  padding: 4px 20px;
  font-size: 13px;
  font-weight: 500;
  color: #767676;
  border-left: 1px solid transparent;
  transition: color .2s, border-color .2s; }
.s2-docs-sidebar .nav > li > a code {
  background-color: inherit;
  color: inherit; }
.s2-docs-sidebar .nav > li > a:hover,
.s2-docs-sidebar .nav > li > a:focus {
  color: #428BCA;
  text-decoration: none;
  background-color: transparent;
  border-left-color: #428BCA; }
.s2-docs-sidebar .nav > .active > a,
.s2-docs-sidebar .nav > .active:hover > a,
.s2-docs-sidebar .nav > .active:focus > a {
  padding-left: 19px;
  font-weight: bold;
  color: #428BCA;
  background-color: transparent;
  border-left: 2px solid #428BCA; }
.s2-docs-sidebar .nav .nav {
  display: none;
  padding-bottom: 10px; }
.s2-docs-sidebar .nav .nav > li > a {
  padding-top: 1px;
  padding-bottom: 1px;
  padding-left: 30px;
  font-size: 12px;
  font-weight: normal; }
.s2-docs-sidebar .nav .nav > li > a:hover,
.s2-docs-sidebar .nav .nav > li > a:focus {
  padding-left: 30px; }
.s2-docs-sidebar .nav .nav > .active > a,
.s2-docs-sidebar .nav .nav > .active:hover > a,
.s2-docs-sidebar .nav .nav > .active:focus > a {
  padding-left: 29px;
  font-weight: 400; }

@media (min-width: 992px) {
  .s2-docs-sidebar .s2-docs-sidenav {
    padding-top: 40px;
    transition: border-color .2s;
    border-left: 1px solid transparent; }

  .s2-docs-sidebar.affix .s2-docs-sidenav {
    border-left-color: #eee; }

  .s2-docs-sidebar .nav > .active > ul {
    display: block; }

  .s2-docs-sidebar.affix,
  .s2-docs-sidebar.affix-bottom {
    width: 213px; }

  .s2-docs-sidebar.affix {
    position: fixed;
    top: 0px; }

  .s2-docs-sidebar.affix-bottom {
    position: absolute; }

  .s2-docs-sidebar.affix-bottom .s2-docs-sidenav,
  .s2-docs-sidebar.affix .s2-docs-sidenav {
    margin-top: 0;
    margin-bottom: 0; } }
@media (min-width: 1200px) {
  .s2-docs-sidebar.affix-bottom,
  .s2-docs-sidebar.affix {
    width: 263px; } }
/* Back to top (hidden on mobile) */
.back-to-top {
  display: none;
  padding: 4px 10px;
  margin-top: 10px;
  margin-left: 10px;
  font-size: 12px;
  font-weight: 400;
  color: #999; }
  .back-to-top:hover {
    color: #428BCA;
    text-decoration: none; }
  @media (min-width: 768px) {
    .back-to-top {
      display: block; } }

.navbar-toggle {
  border: none;
  background: transparent !important; }
  .navbar-toggle:hover {
    background: transparent !important; }
  .navbar-toggle .icon-bar {
    width: 22px;
    transition: all 0.2s; }
  .navbar-toggle .top-bar {
    transform: rotate(45deg);
    transform-origin: 10% 10%; }
  .navbar-toggle .middle-bar {
    opacity: 0; }
  .navbar-toggle .bottom-bar {
    transform: rotate(-45deg);
    transform-origin: 10% 90%; }
  .navbar-toggle.collapsed .top-bar {
    transform: rotate(0); }
  .navbar-toggle.collapsed .middle-bar {
    opacity: 1; }
  .navbar-toggle.collapsed .bottom-bar {
    transform: rotate(0); }

h2 code,
h3 code,
h4 code {
  background-color: inherit; }

pre.prettyprint {
  padding: 9px 14px;
  margin-bottom: 14px;
  background-color: #f7f7f9;
  border: 1px solid #e1e1e8; }

.s2-docs-featurette {
  color: #777;
  padding: 15px 0;
  text-align: center; }
  .s2-docs-featurette h4 {
    margin: 30px 0 15px; }
  .s2-docs-featurette .fa {
    font-size: 28px;
    color: #777; }

.s2-docs-container {
  line-height: 1.6; }

section {
  margin-bottom: 40px; }

.page-header {
  padding-bottom: 19px;
  margin-bottom: 29px; }

.s2-docs-nav {
  margin-bottom: 0;
  border-color: #eee;
  background-color: #f6f6f6; }
  .s2-docs-nav .navbar-brand {
    font-weight: 500; }
    .s2-docs-nav .navbar-brand > img {
      display: inline;
      margin-right: 4px; }
  .s2-docs-nav .navbar-nav > .active > a,
  .s2-docs-nav .navbar-nav > .active > a:hover,
  .s2-docs-nav .navbar-nav > .active > a:focus {
    background-color: #f0f0f0;
    color: #000; }
  @media (min-width: 768px) {
    .s2-docs-nav .navbar-nav > li > .dropdown-menu:before {
      position: absolute;
      top: -21px;
      left: 24px;
      display: block;
      width: 0;
      height: 0;
      border-color: rgba(0, 0, 0, 0) rgba(0, 0, 0, 0) rgba(0, 0, 0, 0.1);
      border-style: solid;
      border-width: 10px;
      content: ""; }
    .s2-docs-nav .navbar-nav > li > .dropdown-menu:after {
      position: absolute;
      top: -20px;
      left: 24px;
      display: block;
      width: 0;
      height: 0;
      border-color: rgba(0, 0, 0, 0) rgba(0, 0, 0, 0) #FFF;
      border-style: solid;
      border-width: 10px;
      content: ''; }
    .s2-docs-nav .navbar-nav .dropdown-menu {
      border-radius: 4px;
      border-color: #ddd;
      margin-top: -1px; } }

.s2-docs-footer {
  border-top: 1px solid #eee;
  color: #767676;
  padding-top: 40px;
  padding-bottom: 40px;
  margin-top: 100px;
  text-align: center; }
  .s2-docs-footer-links {
    padding-left: 0;
    margin-top: 20px; }
  .s2-docs-footer-links li {
    display: inline;
    padding: 0 2px; }
    .s2-docs-footer-links li:after {
      content: "·";
      padding-left: 8px; }
    .s2-docs-footer-links li:first-child {
      padding-left: 0; }
    .s2-docs-footer-links li:last-child:after {
      content: "";
      padding-left: 0; }
  @media (min-width: 768px) {
    .s2-docs-footer p {
      margin-bottom: 0; } }

.alert {
  background: #fff;
  border: 1px solid #eee;
  border-left-width: 5px;
  border-radius: 3px;
  color: #333;
  margin: 20px 0;
  padding: 20px; }
  .alert h4 {
    font-size: 18px;
    margin-top: 0;
    margin-bottom: 5px; }
  .alert-danger {
    border-left-color: #ce4844; }
    .alert-danger h4 {
      color: #ce4844; }
  .alert-info {
    border-left-color: #1b809e; }
    .alert-info h4 {
      color: #1b809e; }
  .alert-warning {
    border-left-color: #aa6708; }
    .alert-warning h4 {
      color: #aa6708; }

.s2-docs-home .jumbotron {
  margin-bottom: 0;
  color: #000; }
  .s2-docs-home .jumbotron h1 {
    color: #000;
    margin-top: 20px; }
.s2-docs-home .lead {
  text-align: center;
  max-width: 800px;
  margin: 0 auto 40px; }
.s2-docs-home .notice-previous {
  background: #f6f6f6;
  color: #666;
  border-bottom: 1px solid #eee;
  padding: 15px 20px; }
.s2-docs-home .half-rule {
  width: 100px;
  margin: 40px auto; }

.s2-example {
  position: relative;
  padding: 45px 15px 15px;
  margin: 0 -15px 15px;
  background-color: #fafafa;
  box-shadow: inset 0 3px 6px rgba(0, 0, 0, 0.05);
  border-color: #e5e5e5 #eee #eee;
  border-style: solid;
  border-width: 1px 0; }
  .s2-example:after {
    content: "Example";
    position: absolute;
    top: 15px;
    left: 15px;
    font-size: 12px;
    font-weight: bold;
    color: #bbb;
    text-transform: uppercase;
    letter-spacing: 1px; }
  @media (min-width: 768px) {
    .s2-example {
      margin-left: 0;
      margin-right: 0;
      background-color: #fff;
      border-width: 1px;
      border-color: #eee;
      border-radius: 4px 4px 0 0;
      box-shadow: none; } }

.s2-event-log {
  background: #002451;
  color: white;
  font-family: Menlo, 'Bitstream Vera Sans Mono', 'DejaVu Sans Mono', Monaco, Consolas, monospace;
  margin: 0 -15px 15px;
  padding: 45px 15px 15px;
  position: relative; }
  .s2-event-log:after {
    content: "Event Log";
    position: absolute;
    top: 15px;
    left: 15px;
    font-size: 12px;
    font-weight: bold;
    color: #BBB;
    text-transform: uppercase;
    letter-spacing: 1px; }
  @media (min-width: 768px) {
    .s2-event-log {
      margin-left: 0;
      margin-right: 0;
      margin-top: -15px;
      border-width: 1px;
      border-color: #eee;
      box-shadow: none; } }

.s2-example + pre,
.s2-example + figure,
.s2-event-log + pre {
  margin: -15px -15px 15px;
  border-radius: 0;
  border-width: 0 0 1px; }
  @media (min-width: 768px) {
    .s2-example + pre,
    .s2-example + figure,
    .s2-event-log + pre {
      margin-top: -16px;
      margin-left: 0;
      margin-right: 0;
      border-width: 1px;
      border-bottom-left-radius: 4px;
      border-bottom-right-radius: 4px; } }

.s2-example + .s2-event-log {
  margin-top: -15px; }

.s2-docs-social {
  margin-bottom: 20px;
  text-align: center; }

.s2-docs-social-buttons {
  display: inline-block;
  padding-left: 0;
  margin-bottom: 0;
  list-style: none; }
  .s2-docs-social-buttons li {
    display: inline-block;
    padding: 5px 8px;
    line-height: 1; }
  .s2-docs-social-buttons .twitter-follow-button {
    width: 225px !important; }
  .s2-docs-social-buttons .twitter-share-button {
    width: 98px !important; }

.github-btn {
  overflow: hidden;
  border: 0; }

.btn-outline-inverse {
  color: #428BCA;
  background-color: transparent;
  border-color: #428BCA;
  padding: 15px 30px;
  font-size: 20px;
  transition: all .1s ease-in-out; }
  .btn-outline-inverse:hover {
    color: #fff;
    border-color: #428BCA;
    background-color: #428BCA; }

.btn-toolbar {
  margin-bottom: 20px; }

.jumbotron {
  background-color: #F6F6F6;
  border-bottom: 1px solid #eee;
  color: #777;
  padding-left: 0;
  padding-right: 0; }
  .jumbotron h1 {
    color: #777;
    font-size: 36px;
    margin-top: 10px; }
  .jumbotron .version {
    color: #999;
    font-size: 14px;
    font-weight: normal;
    margin-bottom: 30px; }

.com {
  color: #999; }

.lit {
  color: #195f91; }

.pun, .opn, .clo {
  color: #93a1a1; }

.fun {
  color: #dc322f; }

.str, .atv {
  color: #C7254E; }

.kwd, .prettyprint .tag {
  color: #2F6F9F; }

.typ, .atn, .dec, .var {
  color: #428BCA; }

.pln {
  color: #333; }

.prettyprint {
  padding: 9px 14px;
  margin-bottom: 20px;
  margin-top: 20px;
  border: 1px solid #eee; }
  .prettyprint.linenums {
    -webkit-box-shadow: inset 40px 0 0 #fbfbfb, inset 41px 0 0 #f6f6f6;
    -moz-box-shadow: inset 40px 0 0 #fbfbfb, inset 41px 0 0 #f6f6f6;
    box-shadow: inset 40px 0 0 #fbfbfb, inset 41px 0 0 #f6f6f6; }

ol.linenums {
  margin: 0 0 0 -12px; }
  ol.linenums li {
    padding-left: 12px;
    color: #bebebe;
    line-height: 18px; }

.highlight {
  background: #fff; }
  .highlight .nx {
    color: #333; }
  .highlight .k, .highlight .o {
    font-weight: bold; }
  .highlight .na {
    color: #428BCA; }
  .highlight .s, .highlight .s1, .highlight .s2, .highlight .sb, .highlight .sc, .highlight .sd, .highlight .se, .highlight .sh, .highlight .si, .highlight .sx {
    color: #C7254E; }
  .highlight .m, .highlight .mf, .highlight mh, .highlight .mi, .highlight .mo {
    color: #195f91; }
  .highlight .p {
    color: #93a1a1; }
  .highlight .nt {
    color: #2F6F9F; }
  .highlight .c {
    color: #999;
    font-style: italic; }
  .highlight .err {
    background-color: #e3d2d2;
    color: #a61717; }
  .highlight .gr {
    color: #a00; }
  .highlight pre {
    border: none;
    margin: 0; }
  .highlight > pre {
    border: 1px solid #eee;
    padding: 0;
    margin-bottom: 14px; }
  .highlight .lineno {
    background-color: #fbfbfb;
    color: #bebebe;
    -ms-user-select: none;
    -moz-user-select: none;
    -webkit-user-select: none; }

.highlight .cm {
  color: #999988;
  font-style: italic; }

/* Comment.Multiline */
.highlight .cp {
  color: #999999;
  font-weight: bold; }

/* Comment.Preproc */
.highlight .c1 {
  color: #999988;
  font-style: italic; }

/* Comment.Single */
.highlight .cs {
  color: #999999;
  font-weight: bold;
  font-style: italic; }

/* Comment.Special */
.highlight .gd {
  color: #000000;
  background-color: #ffdddd; }

/* Generic.Deleted */
.highlight .gd .x {
  color: #000000;
  background-color: #ffaaaa; }

/* Generic.Deleted.Specific */
.highlight .ge {
  font-style: italic; }

/* Generic.Emph */
.highlight .gh {
  color: #999999; }

/* Generic.Heading */
.highlight .gi {
  color: #000000;
  background-color: #ddffdd; }

/* Generic.Inserted */
.highlight .gi .x {
  color: #000000;
  background-color: #aaffaa; }

/* Generic.Inserted.Specific */
.highlight .go {
  color: #888888; }

/* Generic.Output */
.highlight .gp {
  color: #555555; }

/* Generic.Prompt */
.highlight .gs {
  font-weight: bold; }

/* Generic.Strong */
.highlight .gu {
  color: #aaaaaa; }

/* Generic.Subheading */
.highlight .gt {
  color: #aa0000; }

/* Generic.Traceback */
.highlight .kc {
  font-weight: bold; }

/* Keyword.Constant */
.highlight .kd {
  font-weight: bold; }

/* Keyword.Declaration */
.highlight .kp {
  font-weight: bold; }

/* Keyword.Pseudo */
.highlight .kr {
  font-weight: bold; }

/* Keyword.Reserved */
.highlight .kt {
  color: #445588;
  font-weight: bold; }

/* Keyword.Type */
.highlight .nb {
  color: #0086B3; }

/* Name.Builtin */
.highlight .nc {
  color: #445588;
  font-weight: bold; }

/* Name.Class */
.highlight .no {
  color: #008080; }

/* Name.Constant */
.highlight .ni {
  color: #800080; }

/* Name.Entity */
.highlight .ne {
  color: #990000;
  font-weight: bold; }

/* Name.Exception */
.highlight .nf {
  color: #990000;
  font-weight: bold; }

/* Name.Function */
.highlight .nn {
  color: #555555; }

/* Name.Namespace */
.highlight .nv {
  color: #008080; }

/* Name.Variable */
.highlight .ow {
  font-weight: bold; }

/* Operator.Word */
.highlight .w {
  color: #bbbbbb; }

/* Text.Whitespace */
.highlight .sr {
  color: #009926; }

/* Literal.String.Regex */
.highlight .ss {
  color: #990073; }

/* Literal.String.Symbol */
.highlight .bp {
  color: #999999; }

/* Name.Builtin.Pseudo */
.highlight .vc {
  color: #008080; }

/* Name.Variable.Class */
.highlight .vg {
  color: #008080; }

/* Name.Variable.Global */
.highlight .vi {
  color: #008080; }

/* Name.Variable.Instance */
.highlight .il {
  color: #009999; }

/* Literal.Number.Integer.Long */
h1[id] {
  padding-top: 20px;
  margin-top: 0; }

