.logo-title {
    color: #fff;
    font-size: 30px;
    text-transform: uppercase;
    padding-top: 10px;
    vertical-align: middle;
    font-weight: 700;
    font-family: "Montserrat", "Helvetica Neue", "Helvetica" , "Arial" ,sans-serif;
    border-bottom: 2px solid #000000;
}

.logo-image {
    vertical-align:middle;
}

.s2-docs-featurette {
    padding-top: 20px;
    text-align: center;
}

.s2-docs-featurette [class*='size-'] h4 {
    font-size: 1.5rem;
}

/* Padding for paragraphs in featurette grid */
.s2-docs-featurette [class*='size-'] p {
    padding: 0 30px;
    font-size: 1rem !important;
}

.form-control {
    width: 100%;
    display: block;
}

img.img-flag {
    margin: 0 !important;
    display: inherit !important;
    height: 15px;
    width: 18px;
}

/* Override some styles for Select2 component elements */
input.select2-search__field {
    margin-bottom: 0;
    line-height: inherit;
}
